@@ -33,9 +33,10 @@
 #  define KTPOTR_DEPRECATED_NO_EXPORT KTPOTR_NO_EXPORT KTPOTR_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KTPOTR_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KTPOTR_NO_DEPRECATED
+#    define KTPOTR_NO_DEPRECATED
+#  endif
 #endif
 
-#endif
+#endif /* KTPOTR_EXPORT_H */
